<?php
/**
 * @package Frontend
 */

/**
 * Fget the social icon setting and format output
 * @return [string] [social icon information]
 */
function catchwebtools_get_social_icons(){
	$social_settings	=	catchwebtools_get_options( 'catchwebtools_social' );

	$catchwebtools_social_display	= '';

	if ( !( isset( $social_settings['status'] ) &&  $social_settings['status'] ) ) {
		//Bail early if social icon module is disabled
		return $catchwebtools_social_display;
	}

	// Get any existing copy of our transient data
	if ( false === ( $catchwebtools_social_display = get_transient( 'catchwebtools_social_display' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient
		echo '<!-- Refresh CWT Social Icons Cache  --->';

		if ( isset( $social_settings['social_icon_size'] ) || isset( $social_settings['social_icon_color'] ) ) {
				$catchwebtools_social_display .=  '</style>
				<div class="catchwebtools-social"><ul>';
				foreach ( $social_settings as $key => $value ) {
					if ( 'status' == $key || 'social_icon_size' == $key || 'social_icon_color' == $key ) {
						continue;
					}
					if( '' != $value ){
						if ( 'mail' == $key  ) {
							$catchwebtools_social_display .= '<a class="genericon genericon-'. sanitize_key( $key ) .'" target="_blank" title="'. __( 'Email', 'catch-web-tools') . '" href="mailto:'. antispambot( sanitize_email( $value ) ) .'"><span class="screen-reader-text">'. __( 'Email', 'catch-web-tools') . '</span> </a>';
						}
						else if ( 'skype' == $key  ) {
							$catchwebtools_social_display .= '<a class="genericon genericon-'. sanitize_key( $key ) .'" target="_blank" title="'. esc_attr( $value ) . '" href="'. esc_attr( $value ) .'"><span class="screen-reader-text">'. esc_attr( $value ). '</span> </a>';
						}
						else if ( 'phone' == $key || 'handset' == $key ) {
							$catchwebtools_social_display .= '<a class="genericon genericon-'. sanitize_key( $key ) .'" target="_blank" title="'. esc_attr( $value ) . '" href="tel:' . preg_replace( '/\s+/', '', esc_attr( $value ) ) . '"><span class="screen-reader-text">'. esc_attr( $value ) . '</span> </a>';
						}
						else {
							$catchwebtools_social_display .= '<a class="genericon genericon-'. sanitize_key( $key ) .'" target="_blank" title="'. esc_attr( $value ) .'" href="'. esc_url( $value ) .'"><span class="screen-reader-text">'. esc_attr( $value ) .'</span> </a>';
						}
					}
				}
				$catchwebtools_social_display .=  '</ul></div><!-- .catchwebtools-social -->';

			}

		set_transient( 'catchwebtools_social_transient', $social_settings, 7 * DAY_IN_SECONDS );
	}

	return $catchwebtools_social_display;
}



/**
 * Adds CatchWebToolsSocialIcons widget.
 */
class CatchWebToolsSocialIcons extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'catch_web_tools_social_icons', // Base ID
			'CWT Social Icons', // Name
			array( 'description' => __( 'Use this widget to add Catch Web Tools Social Icons as a widget. ', 'catch-web-tools' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		if ( isset( $instance['title'] ) )
			$title = apply_filters( 'widget_title', $instance['title'] );

		echo $args['before_widget'];
		if ( ! empty( $title ) )
			echo $args['before_title'] . $title . $args['after_title'];

		echo catchwebtools_get_social_icons();

		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		if ( isset( $instance['title'] ) ) {
			$title = $instance['title'];
		}
		else {
			$title = __( 'Social Icons', 'catch-web-tools' );
		}
		?>
		<p>
		<label for="<?php echo $this->get_field_name( 'title' ); ?>"><?php _e( 'Title (optional):', 'catch-web-tools' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
        <?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		return $instance;
	}


}

/**
 * Register social widget
 */
function catchwebtools_register_social_widget() {
    register_widget( 'CatchWebToolsSocialIcons' );
}

$social_settings	= catchwebtools_get_options( 'catchwebtools_social' );

if( isset( $social_settings['status'] ) &&  $social_settings['status'] ){
	add_action( 'widgets_init', 'catchwebtools_register_social_widget' );
	add_shortcode( 'cathchemes_social_icons', 'catchwebtools_get_social_icons' );
}

/**
 * Output contents of function catchwebtools_get_social_icons
 * @uses catchwebtools_get_social_icons
 */
function catchwebtools_social_icons(){
	echo catchwebtools_get_social_icons();
}
